camelot.camelot.model.authentication.Party.Admin

Package camelot :: Package camelot :: Package model :: Module authentication :: Class Party :: Class Admin |
[hide private]
[frames] | no frames]

# Class Admin

source code

Instance Methods | [hide private]
Inherited from `view.elixir_admin.EntityAdmin`: `__init__`, `__str__`, `createFormView`, `createNewView`, `createSelectView`, `createTableView`, `createValidator`, `getColumns`, `getFieldAttributes`, `getFields`, `getFilters`, `getForm`, `getFormActions`, `getListCharts`, `getModelThread`, `getName`, `getRelatedEntityAdmin`, `getSubclasses`, `setDefaults` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
| name = `'Parties'`
| list_display = `['name']`
| fields = `['suppliers', 'customers', 'addresses']`
| field_attributes = `dict(suppliers= {'admin': SupplierCustomer.`...``
Inherited from `view.elixir_admin.EntityAdmin`: `form`, `form_actions`, `form_display`, `form_size`, `form_title_column`, `list_actions`, `list_charts`, `list_filter`, `list_size`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### field_attributes Value:
      dict(suppliers= {'admin': SupplierCustomer.SupplierAdmin}, customers=
      {'admin': SupplierCustomer.CustomerAdmin}, employers= {'admin': Employ
      erEmployee.EmployerAdmin}, employees= {'admin': EmployerEmployee.Emplo
      yeeAdmin}, directed_organizations= {'admin': DirectedDirector.Directed
      Admin}, directors= {'admin': DirectedDirector.DirectorAdmin}, shares=
      {'admin': SharedShareholder.SharedAdmin}, shareholders= {'admin': Shar
      edShareholder.ShareholderAdmin}, sex= dict(choices= lambda obj: [(u'M'
      , u'Male'), (u'F', u'Female')],),)